@@ -751,6 +751,10 @@ class Command(Resource):
         # headers['X-UMC-Flavor'] = None
         # X-UMC-IP=self.get_ip_address() ?
         headers['Authorization'] = 'basic ' + base64.b64encode(('%s:%s' % (session.user.username, session.get_umc_password())).encode('ISO8859-1')).decode('ASCII')
+        if session.user.roles is not None:
+            headers['X-UMC-Roles'] = json.dumps(session.user.roles)
+        if session.user.federated_account:
+            headers['X-UMC-Federated-Account'] = json.dumps(True)
         headers['X-UMC-Method'] = methodname
         headers['X-UMC-Command'] = umcp_command.upper()
         headers['X-UMC-Request-ID'] = self._request_id
@@ -1014,6 +1018,8 @@ class UserPreferences(Resource):
         return self.get()
 
     def _get_user_preferences(self, lo):
+        if self.current_user.user.federated_account:
+            return {}
         user_dn = self.current_user.user.user_dn
         if not user_dn or not lo:
             return {}
@@ -1036,6 +1042,8 @@ class SetUserPreferences(UserPreferences):
         "preferences": DictSanitizer({}, required=True),
     }))
     async def post(self):
+        if self.current_user.user.federated_account:
+            return
         lo = self.current_user.get_user_ldap_connection()
         # eliminate double entries
         preferences = self._get_user_preferences(lo)
