@@ -14,7 +14,6 @@ import logging.handlers
 import os
 import resource
 import signal
-import sys
 from argparse import ArgumentParser
 
 import atexit
@@ -25,10 +24,10 @@ from tornado.httpserver import HTTPServer
 from tornado.netutil import bind_sockets
 from tornado.web import Application as TApplication, url
 
-import univention.debug as ud
+import univention.logging as ul
 from univention.management.console import saml
 from univention.management.console.config import env_to_settings, ucr
-from univention.management.console.log import CORE, log_init, log_reopen
+from univention.management.console.log import CORE, init_request_context_logging, log_init, log_reopen
 from univention.management.console.oidc import (
     OIDCBackchannelLogout, OIDCFrontchannelLogout, OIDCLogin, OIDCLogout, OIDCLogoutFinished, OIDCMetadata,
 )
@@ -95,7 +94,7 @@ class Application(TApplication):
 
 
 def tornado_log_reopen():
-    for logname in ('tornado.access', 'tornado.application', 'tornado.general'):
+    for logname in ('tornado', 'tornado.access', 'tornado.application', 'tornado.general', 'tornado.curl_httpclient'):
         logger = logging.getLogger(logname)
         for handler in logger.handlers:
             if isinstance(handler, logging.handlers.RotatingFileHandler):
@@ -134,7 +133,7 @@ class Server:
         # os.environ['LANG'] = locale.normalize(self.options.language)
 
         # init logging
-        log_init(self.options.log_file, self.options.debug, self.options.processes > 1)
+        log_init(self.options.log_file, self.options.debug, self.options.processes > 1, use_structured_logging=ucr.is_true('umc/server/debug/structured-logging'))
 
     def signal_handler_hup(self, signo, frame):
         """Handler for the postrotate action"""
@@ -158,7 +157,7 @@ class Server:
         self._inform_childs(signal)
 
     def signal_handler_stop(self, signo, frame):
-        CORE.warn('Shutting down all open connections')
+        CORE.warning('Shutting down all open connections')
         self._inform_childs(signal)
         raise SystemExit(0)
 
@@ -180,7 +179,7 @@ class Server:
             try:
                 os.kill(pid, signal)
             except OSError as exc:
-                CORE.process('Failed sending signal %d to process %d: %s' % (signal, pid, exc))
+                CORE.process('Failed sending signal %d to process %d: %s', signal, pid, exc)
 
     def run(self):
         n = SystemdNotifier()
@@ -198,7 +197,7 @@ class Server:
             fd_limit = ucr.get_int('umc/http/max-open-file-descriptors', 65535)
             resource.setrlimit(resource.RLIMIT_NOFILE, (fd_limit, fd_limit))
         except (OSError, ValueError) as exc:
-            CORE.error('Could not raise NOFILE resource limits: %s' % (exc,))
+            CORE.error('Could not raise NOFILE resource limits: %s', exc)
 
         # bind sockets
         sockets = bind_sockets(self.options.port, ucr.get('umc/http/interface', '127.0.0.1'), backlog=ucr.get_int('umc/http/requestqueuesize', 100), reuse_port=True)
@@ -209,7 +208,7 @@ class Server:
             umc_settings_obj = settings_data_mod.get(umc_settings_position)
             settings_obj = json.loads(umc_settings_obj.props.data.raw.decode('utf-8'))
         except Exception as exc:
-            CORE.info('Could not read from umc settings/data object. Continuing without shared db session %s' % (exc,))
+            CORE.info('Could not read from umc settings/data object. Continuing without shared db session %s', exc)
         else:
             for env_var, (setting_name, default_setting_value) in env_to_settings.items():
                 if os.environ.get(env_var, None) is None:
@@ -217,7 +216,7 @@ class Server:
                         os.environ[env_var] = settings_obj[setting_name]
                     elif default_setting_value is not None:
                         os.environ[env_var] = default_setting_value
-                        CORE.info('Could not read %s from umc settings/data object. Continuing with default value %s' % (setting_name, default_setting_value))
+                        CORE.info('Could not read %s from umc settings/data object. Continuing with default value %s', setting_name, default_setting_value)
 
         # start sub worker processes
         if self.options.processes != 1:
@@ -228,12 +227,12 @@ class Server:
             if _exit_function is not None:
                 atexit.unregister(_exit_function)
 
-            CORE.process('Starting with %r processes' % (self.options.processes,))
+            CORE.process('Starting with %r processes', self.options.processes)
             n.notify("READY=1")
             try:
                 self._child_number = tornado.process.fork_processes(self.options.processes, 0)
             except RuntimeError as exc:
-                CORE.warn('Child process died: %s' % (exc,))
+                CORE.warning('Child process died: %s', exc)
                 os.kill(os.getpid(), signal.SIGTERM)
                 raise SystemExit(str(exc))
             except KeyboardInterrupt:
@@ -270,16 +269,11 @@ class Server:
         self.server = server
         server.add_sockets(sockets)
 
-        if self.options.log_file in {'stdout', 'stderr', '/dev/stdout', '/dev/stderr'}:
-            channel = logging.StreamHandler(sys.stdout if self.options.log_file in {'stdout', '/dev/stdout'} else sys.stderr)
-        else:
-            channel = logging.handlers.RotatingFileHandler(self.options.log_file, 'a+')
+        ul.extendLogger('tornado', univention_debug_category='NETWORK')
 
-        channel.setFormatter(tornado.log.LogFormatter(fmt='%(color)s%(asctime)s  %(levelname)10s      (%(process)9d) :%(end_color)s %(message)s', datefmt='%d.%m.%y %H:%M:%S'))
-        for logname in ('tornado.access', 'tornado.application', 'tornado.general'):
-            logger = logging.getLogger(logname)
-            logger.setLevel({ud.INFO: logging.INFO, ud.WARN: logging.WARNING, ud.ERROR: logging.ERROR, ud.ALL: logging.DEBUG, ud.PROCESS: logging.INFO}.get(ucr.get_int('umc/server/tornado-debug/level', 0), logging.ERROR))
-            logger.addHandler(channel)
+        handler = logging.getLogger('NETWORK')
+        handler.set_ud_level(ucr.get_int('umc/server/tornado-debug/level', 0))
+        init_request_context_logging('server')
 
         self.reload()
 
@@ -317,14 +311,14 @@ class Server:
             import objgraph
         except ImportError:
             return
-        CORE.warn('### MEMORY')
+        CORE.warning('### MEMORY')
         s = io.StringIO()
         objgraph.show_most_common_types(30, shortnames=False, file=s, filter=lambda o: type(o).__module__.startswith('univention.'))
-        CORE.warn('%s', s.getvalue())
-        CORE.warn('univention.admin.uldap.access: %d', objgraph.count('univention.admin.uldap.access'))
-        CORE.warn('univention.uldap.access: %d', objgraph.count('univention.uldap.access'))
+        CORE.warning('%s', s.getvalue())
+        CORE.warning('univention.admin.uldap.access: %d', objgraph.count('univention.admin.uldap.access'))
+        CORE.warning('univention.uldap.access: %d', objgraph.count('univention.uldap.access'))
         for component in components:
-            CORE.warn('%s: %d', component, objgraph.count('univention.management.console.%s' % (component,)))
+            CORE.warning('%s: %d', component, objgraph.count('univention.management.console.%s' % (component,)))
 
         # objgraph.show_backrefs(objgraph.by_type('univention.uldap.access')[0])
 
